/*
  FootMouseController

 2016.8.27r1 - c. niggel

 Driver for pressure-operated mouse control.  Uses 8 analog pins to control mouse
 movements.

 Based on JoystickMouseControl from Tom Igoe

 Hardware:
 * 8 pads connected to analog pins, see configuration below

 The mouse movement is always relative. This sketch reads
 analog inputs that range from 0 to 1023 (or less on either end)
 and translates them into ranges of -8 to 8.
 The sketch assumes that the resting values are around the
 middle of the range, but that they vary within a threshold.

 */

#include "Mouse.h"

// set pin numbers for pads:  Left/Right refer to the positioning of the pads, you may need
// to modify the pin assignments depending on your construction
const int RIGHT_UP = A4; 
const int RIGHT_DOWN = A5; 
const int RIGHT_LEFT = A9; 
const int RIGHT_RIGHT = A10; 
const int LEFT_UP = A0;
const int LEFT_DOWN = A1; // should be A3
const int LEFT_LEFT = A3;  // should be A1 
const int LEFT_RIGHT = A2;

// parameters for setting the range and threshold:
int range = 8;               // output range of X or Y movement. Tunes speed
int responseDelay = 5;        // response delay of the mouse, in ms. Tunes response
int threshold = 3;    // resting threshold. Tunes dead-zone

void setup() {
  pinMode(RIGHT_UP, INPUT);
  pinMode(RIGHT_DOWN, INPUT);
  pinMode(RIGHT_LEFT, INPUT);
  pinMode(RIGHT_RIGHT, INPUT);
  pinMode(LEFT_UP, INPUT);
  pinMode(LEFT_DOWN, INPUT);
  pinMode(LEFT_LEFT, INPUT);
  pinMode(LEFT_RIGHT, INPUT);
  
  // take control of the mouse:
  Mouse.begin();
  // print to serial:
  //Serial.begin(9600);
}

void loop() {
  // read and scale movement pads:
  int right_up = (0 -readPressure(RIGHT_UP));
  int right_down = readPressure(RIGHT_DOWN);
  int right_left = (0 - readPressure(RIGHT_LEFT));
  int right_right = readPressure(RIGHT_RIGHT);

  int xAxis = (right_left+right_right);
  int yAxis = (right_up+right_down);
  int zAxis = 0;
  
  // the LEFT_DOWN is a modifier for scrolling.
  // It converts the output from y axis to z axis, reduces speed, increases delay,
  // and flips y axis to emulate a scroll wheel
  int left_down = readPressure(LEFT_DOWN);
  if (left_down > 0) {
    zAxis = yAxis;
    zAxis = map(zAxis, 0, range, 0, (range/4));
    zAxis = -zAxis;
    yAxis = 0;
    delay(80);
    }
  
  // move the mouse
  Mouse.move(xAxis, yAxis, zAxis);

  //uncomment to debug
  //Serial.print("X: ");
  //Serial.print(xAxis);
  //Serial.print(" Y: ");
  //Serial.print(yAxis);
  //Serial.print(" Z: ");
  //Serial.print(zAxis);
  //Serial.print("   ");
   
 
  //read and scale button pads:
  int left_up = readPressure(LEFT_UP);
  int left_left = readPressure(LEFT_LEFT);
  int left_right = readPressure(LEFT_RIGHT);

  //if left button is pressed, send mousedown
  if (left_left > 0) {
    // if the mouse is not pressed, press it:
    if (!Mouse.isPressed(MOUSE_LEFT)) {
      Mouse.press(MOUSE_LEFT);
      //Serial.print(" LD ");
    }
  }
  // else the mouse button is not pressed:
  else {
    // if the mouse is pressed, release it:
    if (Mouse.isPressed(MOUSE_LEFT)) {
      Mouse.release(MOUSE_LEFT);
    }
  }
  
  //if right button is pressed, send mousedown
  if (left_right > 0) {
    // if the mouse is not pressed, press it:
    if (!Mouse.isPressed(MOUSE_RIGHT)) {
      Mouse.press(MOUSE_RIGHT);
      //Serial.print(" RD ");
    }
  }
  // else the mouse button is not pressed:
  else {
    // if the mouse is pressed, release it:
    if (Mouse.isPressed(MOUSE_RIGHT)) {
      Mouse.release(MOUSE_RIGHT);
    }
  }

  // if the top button is pressed, send a double-click
  if (left_up > 0) {
    // if the mouse is not pressed, press it:
    if (!Mouse.isPressed(MOUSE_LEFT)) {
      Mouse.click(MOUSE_LEFT);
      delay(10);
      Mouse.click(MOUSE_LEFT);
      delay(250);
      //Serial.print(" DC ");
    }
  }
  

  delay(responseDelay);

  //Serial.println(".");
}

/*
 * readPressure - takes int to define Pad, outputs value from 0-<range>
 */

int readPressure(int Pad) {
  // read the analog input
  int reading = analogRead(Pad);

  //map the reading from the input range to the output range
  reading = map(reading, 0, 1023, 0, range);

  //if the output reading is outside from the rest threshold, use it

  if (abs(reading) < threshold) {
    reading = 0;
  }

  return reading;
}



